scxpand.autoencoders.ae\_trainer
================================

.. automodule:: scxpand.autoencoders.ae_trainer

   
   .. rubric:: Functions

   .. autosummary::
   
      calculate_training_metrics
      run_ae_inference
      run_ae_trainer
   